@@ -91,6 +91,7 @@ describe 'neutron' do
     it_configures 'with dns_domain defined'
     it_configures 'with transport_url defined'
     it_configures 'with rootwrap daemon'
+    it_configures 'with max_allowed_address_pair defined'
 
     context 'with amqp messaging' do
       it_configures 'amqp support'
@@ -279,7 +280,7 @@ describe 'neutron' do
         :use_syslog         => false,
       )
     end
-    it { is_expected.to contain_neutron_config('DEFAULT/use_syslog').with_value(false) }
+    it { is_expected.to contain_neutron_config('DEFAULT/use-syslog').with_value(false) }
   end
 
   shared_examples_for 'with non-default kombu options' do
@@ -366,7 +367,7 @@ describe 'neutron' do
     end
 
     it do
-      is_expected.to contain_neutron_config('DEFAULT/use_syslog').with_value(true)
+      is_expected.to contain_neutron_config('DEFAULT/use-syslog').with_value(true)
     end
   end
 
@@ -378,8 +379,8 @@ describe 'neutron' do
       )
     end
     it 'configures logging' do
-      is_expected.to contain_neutron_config('DEFAULT/log_file').with_value(params[:log_file])
-      is_expected.to contain_neutron_config('DEFAULT/log_dir').with_value(params[:log_dir])
+      is_expected.to contain_neutron_config('DEFAULT/log-file').with_value(params[:log_file])
+      is_expected.to contain_neutron_config('DEFAULT/log-dir').with_value(params[:log_dir])
     end
   end
 
@@ -520,6 +521,18 @@ describe 'neutron' do
     end
   end
 
+  shared_examples_for 'with max_allowed_address_pair defined' do
+    before do
+      params.merge!(
+        :max_allowed_address_pair => '50'
+      )
+    end
+
+    it do
+      is_expected.to contain_neutron_config('DEFAULT/max_allowed_address_pair').with_value(params[:max_allowed_address_pair])
+    end
+  end
+
   context 'on Debian platforms' do
     let :facts do
       @default_facts.merge(test_facts.merge({
